@@ -29,7 +29,9 @@ def countplot(x, data, hue=None, prop=False, sort_by="count", ascending=False):
     if prop:
         _["display"] = _.iloc[:, 1].apply(
             lambda x: str(int(round(x / total * 100))) + "%")
-    g = sns.barplot(x=x, y=_.columns[1], data=_, hue=hue)
+    # add fake col to normalize the bar's sequences
+    _[" "+x+" "] = _[x].apply(lambda x:""+str(x))
+    g = sns.barplot(x=" "+x+" ", y=_.columns[1], data=_, hue=hue)
     # 在柱状图的上面显示各个类别的数量
     for index, row in _.iterrows():
         # 在柱状图上绘制该类别的数量
@@ -61,36 +63,40 @@ if __name__ == "__main__":
     # plt.legend()
     # plt.show()
 
-    def classify(x):
-        if x == 0:
-            return "差"
-        elif x == 1:
-            return "中"
-        else:
-            return "好"
+    # def classify(x):
+    #     if x == 0:
+    #         return "差"
+    #     elif x == 1:
+    #         return "中"
+    #     else:
+    #         return "好"
+    #
+    #
+    # def subject(x):
+    #     if x == 0:
+    #         return "文科"
+    #     else:
+    #         return "理科"
+    #
+    #
+    # df = pd.DataFrame(np.random.randint(0, 3, (10, 2)), columns="语文,数学".split(","))
+    # df["语文"] = df["语文"].apply(lambda x: classify(x))
+    # df["数学"] = df["数学"].apply(lambda x: classify(x))
+    # df["分科"] = df["语文"].apply(lambda x: subject(np.random.randint(0, 2)))
+    # print(df)
+    #
+    # plt.subplot(1, 2, 1)
+    # sns.countplot(x="语文", data=df)
+    # plt.subplot(1, 2, 2)
+    # sns.countplot(x="语文", hue="分科", data=df)
+    # plt.show()
+    #
+    # countplot(x="语文", data=df, prop=True)
+    # plt.show()
+    #
+    # sns.countplot(x="语文", hue="分科", data=df)
+    # plt.show()
 
-
-    def subject(x):
-        if x == 0:
-            return "文科"
-        else:
-            return "理科"
-
-
-    df = pd.DataFrame(np.random.randint(0, 3, (10, 2)), columns="语文,数学".split(","))
-    df["语文"] = df["语文"].apply(lambda x: classify(x))
-    df["数学"] = df["数学"].apply(lambda x: classify(x))
-    df["分科"] = df["语文"].apply(lambda x: subject(np.random.randint(0, 2)))
-    print(df)
-
-    plt.subplot(1, 2, 1)
-    sns.countplot(x="语文", data=df)
-    plt.subplot(1, 2, 2)
-    sns.countplot(x="语文", hue="分科", data=df)
-    plt.show()
-
-    countplot(x="语文", data=df, prop=True)
-    plt.show()
-
-    sns.countplot(x="语文", hue="分科", data=df)
+    df = pd.DataFrame(np.random.randint(0,10,(10,3)),columns=list("abc"))
+    countplot("a",df)
     plt.show()
